@@ -41,6 +41,7 @@
 #include "hrm_shared.h"
 #include "ec_error.h"
 #include "settings.h"
+#include "general_settings.h"
 #include "target_heart_rate.h"
 #include "calculate_bmi.h"
 #include "calculate_maxheartrate.h"
@@ -66,6 +67,14 @@ static void interface_default_folder_changed(
 		const GConfEntry *entry,
 		gpointer user_data,
 		gpointer user_data_2);
+static void interface_measuring_units_changed(
+		const GConfEntry *entry,
+		gpointer user_data,
+		gpointer user_data_2);
+static void interface_display_state_changed(
+		const GConfEntry *entry,
+		gpointer user_data,
+		gpointer user_data_2);
 
 static void interface_minimize(GtkWidget *btn, gpointer user_data);
 static void interface_confirm_close(GtkWidget *btn, gpointer user_data);
@@ -235,7 +244,17 @@ AppData *interface_create()
 			interface_default_folder_changed,
 			app_data,
 			NULL);
+	
+	/* Set default measuring units */
+	gconf_helper_add_key_bool(app_data->gconf_helper,USE_METRIC,TRUE,
+				  interface_measuring_units_changed,app_data,
+      				  NULL);
 
+	/* Set default display state */
+	gconf_helper_add_key_bool(app_data->gconf_helper,DISPLAY_ON,TRUE,
+				  interface_display_state_changed,app_data,
+				  NULL);
+	
 	/* Finalize the main window */
 	gtk_container_add(GTK_CONTAINER(app_data->window),
 			app_data->navigation_menu->main_widget);
@@ -400,10 +419,10 @@ static void interface_create_menu(AppData *app_data)
 	navigation_menu_item_new_for_path(
 			app_data->navigation_menu,
 			path_level_1,
-			_("Edit activities"),
-			NULL,
-			NULL,
-			NULL,
+			_("General\nsettings"),
+			GFXDIR "menu_settings_btn",
+			show_general_settings,
+			app_data,
 			FALSE);
 
 	navigation_menu_item_new_for_path(
@@ -453,6 +472,44 @@ static void interface_initialize_gconf(AppData *app_data)
 	DEBUG_END();
 }
 
+
+static void interface_measuring_units_changed(
+		const GConfEntry *entry,
+		gpointer user_data,
+		gpointer user_data_2)
+{
+	GConfValue *value = NULL;
+	AppData *app_data = (AppData *)user_data;
+	const gchar *use_metric;
+
+	g_return_if_fail(app_data != NULL);
+	g_return_if_fail(entry != NULL);
+	DEBUG_BEGIN();
+
+	value = gconf_entry_get_value(entry);
+	use_metric = gconf_value_get_bool(value);
+	DEBUG_END();
+	
+}
+
+static void interface_display_state_changed(
+		const GConfEntry *entry,
+		gpointer user_data,
+		gpointer user_data_2)
+{
+	GConfValue *value = NULL;
+	AppData *app_data = (AppData *)user_data;
+	const gchar *display_on;
+
+	g_return_if_fail(app_data != NULL);
+	g_return_if_fail(entry != NULL);
+	DEBUG_BEGIN();
+
+	value = gconf_entry_get_value(entry);
+	display_on = gconf_value_get_bool(value);
+	DEBUG_END();
+}
+
 static void interface_default_folder_changed(
 		const GConfEntry *entry,
 		gpointer user_data,
